Create a random effects covariance parameter object for use with other functions.
randcov_params(..., nm)A named numeric vector of random effect covariance parameters.
Names of the random effects should match eligible names given to
random in modeling functions. While with the random
argument to these functions, an
intercept is implicitly assumed, with randcov_params, an intercept must be
explicitly specified. That is, while with random, x | group
is shorthand for (1 | group) + (x | group), with randcov_params,
x | group implies just x | group, which means that if 1 | group
is also desired, it must be explicitly specified.
randcov_params(group = 1, subgroup = 2)
#> group subgroup
#> 1 2
randcov_params(1, 2, nm = c("group", "subgroup"))
#> group subgroup
#> 1 2
# same as
randcov_params("1 | group" = 1, "1 | subgroup" = 2)
#> 1 | group 1 | subgroup
#> 1 2