Learn R Programming

spmodel (version 0.14.0)

satterthwaite.splm: Compute Satterthwaite denominator degrees of freedom

Description

Compute Satterthwaite denominator degrees of freedom \(t\)-based (rather than asymptotic \(z\)-based) fixed effect inference in small samples.

Usage

# S3 method for splm
satterthwaite(object, method, ...)

# S3 method for spautor satterthwaite(object, method, ...)

satterthwaite(object, ...)

Value

A named numeric vector of Satterthwaite degrees of freedom for each fixed effect.

Arguments

object

A fitted model object from splm() or spautor().

method

The method by which to compute gradients. "numeric" for numerical differentiation and "closed" for closed form solutions. The default "closed" for "exponential", "gaussian", "spherical", "none", and "ie" spatial covariance functions (without anisotropy) and "numeric" otherwise.

...

Other arguments. Not used (needed for generic consistency).

Details

Satterthwaite degrees of freedom are generally more appropriate than asymptotic degrees of freedom for small samples. They can be computationally costly for sample sizes exceeding 500; however, for sample sizes this large, they Satterthwaite and asymptotic degrees of freedom should yield very similar inferences.

References

Rencher, Alvin C. and Schaalje, G. Bruce (2008). Linear Models in Statistics, Second Edition. John Wiley & Sons.

See Also

splm() spautor() anova.spmodel()

Examples

Run this code
# \donttest{
spmod <- splm(z ~ water + tarp,
  data = caribou,
  spcov_type = "exponential", xcoord = x, ycoord = y, estmethod = "reml"
)
satterthwaite(spmod)
# }

Run the code above in your browser using DataLab