View source: R/decorrelate_grid.R
| decorrelate_grid | R Documentation |
Create a spatial decorrelation transformation grid of initial parameters to be evaluated via a grid search.
decorrelate_grid(
formula,
data,
spcov_type,
spcov_params,
xcoord,
ycoord,
anisotropy = FALSE,
random,
randcov_params,
dense_grid
)
formula |
A two-sided linear formula describing the fixed effect structure
of the model, with the response to the left of the |
data |
A data frame or |
spcov_type |
The spatial covariance type. Available options include
|
spcov_params |
An object from |
xcoord |
The name of the column in |
ycoord |
The name of the column in |
anisotropy |
A logical indicating whether (geometric) anisotropy should
be modeled. Not required if the |
random |
A one-sided linear formula describing the random effect structure
of the model. Terms are specified to the right of the |
randcov_params |
An object from |
dense_grid |
A logical
which controls the density of the constructed grid to be evaluated. If
|
A grid of spatial decorrelation parameters stored as a data.frame.
decorrelate_grid(log_cond ~ temp, data = lake, spcov_type = "exponential")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.