View source: R/decorrelate_newdata.R
| decorrelate_newdata | R Documentation |
Apply the spatial decorrelation transformation to a newdata object. This object contains explanatory variables that are transformed for prediction accoring to some spatial decorrelation transformation.
decorrelate_newdata(object, newdata, local, ...)
object |
A |
newdata |
A data frame or |
local |
A optional logical or list controlling the big data approximation.
If omitted,
When |
... |
Other arguments. |
A list with many elements that store information about the fitted model object. Importantly, the list contains the following element:
X_newdata: The original fixed effects design matrix (of explanatory variables) for the prediction data.
tX_newdata: The spatially decorrelated fixed effects design matrix for the prediction data.
params <- spcov_params("exponential", de = 1, ie = 0.2, range = 1e5)
decorr <- decorrelate_data(log_cond ~ temp, data = lake, spcov_params = params)
decorr_newdata <- decorrelate_newdata(decorr, newdata = lake_preds)
head(decorr_newdata$tX_newdata)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.