View source: R/satterthwaite.R
| satterthwaite.splm | R Documentation |
Compute Satterthwaite denominator degrees of freedom
t-based (rather than asymptotic z-based)
fixed effect inference in small samples.
## S3 method for class 'splm'
satterthwaite(object, method, ...)
## S3 method for class 'spautor'
satterthwaite(object, method, ...)
satterthwaite(object, ...)
object |
A fitted model object from |
method |
The method by which to compute gradients. |
... |
Other arguments. Not used (needed for generic consistency). |
Satterthwaite degrees of freedom are generally more appropriate than asymptotic degrees of freedom for small samples. They can be computationally costly for sample sizes exceeding 500; however, for sample sizes this large, they Satterthwaite and asymptotic degrees of freedom should yield very similar inferences.
A named numeric vector of Satterthwaite degrees of freedom for each fixed effect.
Rencher, Alvin C. and Schaalje, G. Bruce (2008). Linear Models in Statistics, Second Edition. John Wiley & Sons.
splm() spautor() anova.spmodel()
spmod <- splm(z ~ water + tarp,
data = caribou,
spcov_type = "exponential", xcoord = x, ycoord = y, estmethod = "reml"
)
satterthwaite(spmod)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.