Compute Satterthwaite denominator degrees of freedom \(t\)-based (rather than asymptotic \(z\)-based) fixed effect inference in small samples.

# S3 method for class 'splm'
satterthwaite(object, method, ...)

# S3 method for class 'spautor'
satterthwaite(object, method, ...)

satterthwaite(object, ...)

Arguments

object

A fitted model object from splm() or spautor().

method

The method by which to compute gradients. "numeric" for numerical differentiation and "closed" for closed form solutions. The default "closed" for "exponential", "gaussian", "spherical", "none", and "ie" spatial covariance functions (without anisotropy) and "numeric" otherwise.

...

Other arguments. Not used (needed for generic consistency).

Value

A named numeric vector of Satterthwaite degrees of freedom for each fixed effect.

Details

Satterthwaite degrees of freedom are generally more appropriate than asymptotic degrees of freedom for small samples. They can be computationally costly for sample sizes exceeding 500; however, for sample sizes this large, they Satterthwaite and asymptotic degrees of freedom should yield very similar inferences.

References

Rencher, Alvin C. and Schaalje, G. Bruce (2008). Linear Models in Statistics, Second Edition. John Wiley & Sons.

Examples

# \donttest{
spmod <- splm(z ~ water + tarp,
  data = caribou,
  spcov_type = "exponential", xcoord = x, ycoord = y, estmethod = "reml"
)
satterthwaite(spmod)
#> (Intercept)      waterY    tarpnone   tarpshade 
#>   0.0115194  22.3957003  20.2596846  18.7509208 
# }