Summarize a fitted model object.

# S3 method for splm
summary(object, ...)

# S3 method for spautor
summary(object, ...)

# S3 method for spglm
summary(object, ...)

# S3 method for spgautor
summary(object, ...)

Arguments

object

A fitted model object from splm(), spautor(), spglm(), or spgautor().

...

Other arguments. Not used (needed for generic consistency).

Value

A list with several fitted model quantities used to create informative summaries when printing.

Details

summary() creates a summary of a fitted model object intended to be printed using print(). This summary contains useful information like the original function call, residuals, a coefficients table, a pseudo r-squared, and estimated covariance parameters.

See also

Examples

spmod <- splm(z ~ water + tarp,
  data = caribou,
  spcov_type = "exponential", xcoord = x, ycoord = y
)
summary(spmod)
#> 
#> Call:
#> splm(formula = z ~ water + tarp, data = caribou, spcov_type = "exponential", 
#>     xcoord = x, ycoord = y)
#> 
#> Residuals:
#>      Min       1Q   Median       3Q      Max 
#> -0.41321 -0.20784 -0.11238  0.02915  0.45415 
#> 
#> Coefficients (fixed):
#>             Estimate Std. Error z value Pr(>|z|)    
#> (Intercept)  2.05021    0.30373   6.750 1.48e-11 ***
#> waterY      -0.08336    0.06443  -1.294 0.195745    
#> tarpnone     0.08006    0.07750   1.033 0.301564    
#> tarpshade    0.28663    0.07657   3.743 0.000181 ***
#> ---
#> Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1
#> 
#> Pseudo R-squared: 0.3972
#> 
#> Coefficients (exponential spatial covariance):
#>       de       ie    range 
#>  0.10672  0.02244 18.01186